@@ -4,7 +4,7 @@ import os
 import re
 import warnings
 
-from .helpers import (section_to_string, CustomDict, convert_section, InpSection,
+from .helpers import (section_to_string, CustomDict, convert_section, InpSection, InpSectionGeo,
                       InpSectionGeneric, SECTION_ORDER_DEFAULT, check_order, SECTIONS_ORDER_MP, head_to_str,
                       iter_section_lines, SwmmInputWarning, BaseSectionObject, )
 from .._io_helpers import get_default_encoding, read_txt_file
@@ -336,7 +336,7 @@ class SwmmInput(CustomDict):
         """
         if hasattr(section_class, '_section_label'):  # BaseSectionObject
             section_label = section_class._section_label
-            new_empty_section = section_class.create_new_empty()
+            new_empty_section = section_class.create_section()
         elif hasattr(section_class, '_label'):  # InpSectionGeneric
             section_label = section_class._label
             new_empty_section = section_class()
@@ -501,7 +501,7 @@ class SwmmInput(CustomDict):
         POLYGONS section
 
         Returns:
-            dict[str, Polygon] | InpSectionGeo: Polygon section
+            dict[str, Polygon] or InpSectionGeo: Polygon section
         """
         if POLYGONS in self:
             return self[POLYGONS]
